@@ -68,6 +68,10 @@ macro_rules! select_view {
             temp_sv
         }
     };
+
+    ($($label:expr), *) => {
+        select_view!($($label => $label), *)
+    }
 }
 
 /// Convenience macro that generates a settings view using sub-views wrapped in a `Dialog` view
